'''
	Mic Live Display
	Triggered by a GPIO closing contact, this script will change the fullscreen image.
	Author: Marc Steele
	Date: August 2014
'''

# Settings

image_live_path = '/home/pi/live.jpg'
image_off_path = '/home/pi/off.jpg'
gpio_pin = 17

# Imports

import RPi.GPIO as GPIO
import pygame
from pygame.locals import *

# Figure out our fullscreen resolution

pygame.init();
display_info = pygame.display.Info()
width = display_info.current_w
height = display_info.current_h
print('Got a display resolution of %s by %s.' % (width, height))

# Seup the display and hide the mouse

screen = pygame.display.set_mode((width, height), FULLSCREEN)
pygame.mouse.set_visible(False)

# Configure GPIO

GPIO.setmode(GPIO.BCM)
GPIO.setup(gpio_pin, GPIO.IN, pull_up_down = GPIO.PUD_DOWN)

# Load the images

image_live = pygame.image.load(image_live_path);
image_off = pygame.image.load(image_off_path);

image_live = pygame.transform.scale(image_live, (width, height)).convert()
image_off = pygame.transform.scale(image_off, (width, height)).convert()


# Display the initial screen

screen.fill((0, 0, 0))
screen.blit(image_off, (0, 0))
pygame.display.flip()

# The display / GPIO loop

mode = False

while True:

	# Figure out what mode we're in

	mode = (GPIO.input(gpio_pin) == 1)

	# Change the display

	screen.fill((0, 0, 0))

	if (mode):
		screen.blit(image_live, (0, 0))
		mode = False
	else:
		screen.blit(image_off, (0, 0))
		mode = True

	pygame.display.flip()

	# Sleep it off

	pygame.time.wait(250)
